# -*- coding: utf-8 -*-

from django.contrib import admin
from django_admin import ReadOnlyModelAdmin

from equipment.models import (AepThermometerMeasureLogInfo, AntigenMeasureLogInfo, IsolationPointFieldPoolInfo,
                              IsolationPointInfo, IsolationPointUserInfo, ThermometerEquipmentInfo,
                              ThermometerMeasureLogInfo, FamilyMemberInfo)


class IsolationPointFieldPoolInfoAdmin(admin.ModelAdmin):
    list_display = ('field_type', 'field_key', 'field_name', 'field_options', 'status', 'created_at', 'updated_at')


class IsolationPointInfoAdmin(admin.ModelAdmin):
    list_display = ('point_id', 'point_name', 'point_fields', 'point_upload_period', 'temperature_measure_type', 'limit_scene_qrcode_url', 'status', 'created_at', 'updated_at')


class IsolationPointUserInfoAdmin(admin.ModelAdmin):
    list_display = ('point_id', 'user_id', 'fields', 'observed_days', 'chg_sta', 'temperature', 'last_submit_at', 'leave_at', 'status', 'created_at', 'updated_at')


class FamilyMemberInfoAdmin(admin.ModelAdmin):
    list_display = ('member_id', 'user_id', 'identity_card_number', 'identity_card_name', 'relation', 'status', 'created_at', 'updated_at')


class ThermometerEquipmentInfoAdmin(admin.ModelAdmin):
    list_display = ('eqpt_id', 'point_id', 'macid', 'sn', 'active_status', 'active_at', 'ipui_pk', 'status', 'created_at', 'updated_at')
    list_filter = ('point_id', 'status')


class ThermometerMeasureLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('point_id', 'macid', 'sn', 'start_stamp', 'end_stamp', 'temperature_src', 'temperature', 'chg_sta', 'ignore_temperature', 'ignore_fever_temperature', 'status', 'created_at', 'updated_at')
    list_filter = ('point_id', 'temperature_src', 'chg_sta', 'ignore_temperature', 'ignore_fever_temperature', 'status')


class AepThermometerMeasureLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('imei', 'temperature_src', 'temperature', 'battery', 'status', 'created_at', 'updated_at')


class AntigenMeasureLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('point_id', 'user_id', 'macid', 'phone', 'user_name', 'result', 'detect_at', 'created_at', 'updated_at')


admin.site.register(IsolationPointFieldPoolInfo, IsolationPointFieldPoolInfoAdmin)
admin.site.register(IsolationPointInfo, IsolationPointInfoAdmin)
admin.site.register(IsolationPointUserInfo, IsolationPointUserInfoAdmin)
admin.site.register(ThermometerEquipmentInfo, ThermometerEquipmentInfoAdmin)
admin.site.register(ThermometerMeasureLogInfo, ThermometerMeasureLogInfoAdmin)
admin.site.register(AepThermometerMeasureLogInfo, AepThermometerMeasureLogInfoAdmin)
admin.site.register(AntigenMeasureLogInfo, AntigenMeasureLogInfoAdmin)
admin.site.register(FamilyMemberInfo, FamilyMemberInfoAdmin)

